@@ -3,6 +3,7 @@ Obsplot jsdom handling.
 """
 
 import subprocess
+import os
 import json
 import shutil
 from IPython.display import HTML, SVG
@@ -22,14 +23,15 @@ class ObsplotJsdom:
     Python kwargs.
     """
 
-    def __init__(self, spec: Any, debug: bool = False) -> None:
+    def __init__(self, spec: Any, default: dict = {}, debug: bool = False) -> None:
         """
         Constructor. Parse the spec given as argument.
         """
         # Create parser
-        parser = SpecParser("jsdom")
+        parser = SpecParser(renderer="jsdom", default=default)
         # Parse spec code
-        code = parser.parse(spec)
+        parser.spec = spec
+        code = parser.parse_spec()
         # Create spec object
         spec = {"data": parser.serialize_data(), "code": code, "debug": debug}
         self.spec = spec
@@ -51,6 +53,9 @@ class ObsplotJsdom:
             input=json.dumps(self.spec),
             capture_output=True,
             encoding="Utf8",
+            # Use shell=True if we are on Windows. Otherwise PATH
+            # is not parsed and npx is not found.
+            shell=os.name == "nt",
         )
         if p.returncode != 0:
             raise RuntimeError(
